@@ -6,7 +6,7 @@ import logging
 from collections import defaultdict
 from typing import TYPE_CHECKING, Optional, Collection, Any
 
-from .args import Args
+from .context import Context
 from .exceptions import CommandDefinitionError, ParameterDefinitionError
 from .formatting import HelpFormatter
 from .parameters import (
@@ -35,6 +35,7 @@ class CommandParameters:
     action: Optional[Action] = None
     _pass_thru: Optional[PassThru] = None
     sub_command: Optional[SubCommand] = None
+    action_flags: list[ActionFlag]
     options: list[BaseOption]
     combo_option_map: dict[str, BaseOption]
     groups: list[ParamGroup]
@@ -96,7 +97,7 @@ class CommandParameters:
                 if self.pass_thru:
                     raise CommandDefinitionError(f'Invalid PassThru {param=} - it cannot follow another PassThru param')
                 self._pass_thru = param
-                self.formatter.maybe_add(param)
+                self.formatter.maybe_add_param(param)
             else:
                 raise CommandDefinitionError(
                     f'Unexpected type={param.__class__} for {param=} - custom parameters must extend'
@@ -108,7 +109,7 @@ class CommandParameters:
         self._process_groups(groups)
 
     def _process_groups(self, groups: list[ParamGroup]):
-        self.formatter.maybe_add(*groups)
+        self.formatter.maybe_add_group(*groups)
         if parent := self.parent:
             groups = parent.groups + groups
         self.groups = sorted(groups)
@@ -142,7 +143,7 @@ class CommandParameters:
                 var_nargs_param = param
 
         self.positionals = params
-        self.formatter.maybe_add(*params)
+        self.formatter.maybe_add_param(*params)
 
     def _process_options(self, params: Collection[BaseOption]):
         if parent := self.parent:
@@ -169,7 +170,7 @@ class CommandParameters:
                             f'{opt_type}={opt!r} conflict for command={self.command!r} between {existing} and {param}'
                         )
 
-        self.formatter.maybe_add(*options)
+        self.formatter.maybe_add_param(*options)
         self.options = options
         self.option_map = option_map
         self._process_action_flags(options)
@@ -252,7 +253,7 @@ class CommandParameters:
         key, value = option[1], option[2:]
         # value will never be empty if key is a valid option because by this point, option is not a short option
         param = self.combo_option_map[key]
-        if param.would_accept(Args([]), value, short_combo=True):  # TODO: Refactor would_accept
+        if param.would_accept(Context.get_current(), value, short_combo=True):
             return [(param, value)]
         else:
             combo_option_map = self.combo_option_map
@@ -288,16 +289,3 @@ class CommandParameters:
         return None
 
     # endregion
-
-    def args_to_dict(self, args: 'Args', exclude: Collection[Parameter] = ()) -> dict[str, Any]:
-        if (parent := self.parent) is not None:
-            arg_dict = parent.args_to_dict(args, exclude)
-        else:
-            arg_dict = {}
-
-        for group in (self.positionals, self.options, (self.pass_thru,)):
-            for param in group:
-                if param and param not in exclude:
-                    arg_dict[param.name] = param.result_value(args)
-
-        return arg_dict
